@@ -8,7 +8,7 @@ import datetime
 
 
 class ElasticSearchCommand(Command):
-    def __init__(self, response, status_code, index, doc, params=None, headers=None):
+    def __init__(self, response, status_code, index, doc, args, params=None, headers=None):
         super(ElasticSearchCommand, self).__init__()
         if headers is None:
             headers = {}
@@ -18,6 +18,7 @@ class ElasticSearchCommand(Command):
         self._status_code = status_code
         self._index = index
         self._doc = doc
+        self._args = args
         self._params = params
         self._headers = headers
 
@@ -30,6 +31,7 @@ class ElasticSearchCommand(Command):
                 created_at = datetime.datetime.now(tz=CURRENT_TIME_ZONE)
                 index = self._index
                 doc = self._doc
+                args = self._args
                 params = self._params
                 headers = self._headers
                 client = ElasticSearchClient.get_client()
@@ -39,7 +41,8 @@ class ElasticSearchCommand(Command):
                     'data': self.clean_data_type(response.get('data')),
                     'metadata': metadata,
                     'transaction': self.clean_data_type(transaction),
-                    'created_at': created_at
+                    'created_at': created_at,
+                    'args': args
                 }
                 if response.get('error'):
                     error = response.get('error')
@@ -66,7 +69,7 @@ class ElasticSearchCommand(Command):
     def clean_data_type(self, data):
         if data is None:
             return []
-        if type(data):
+        if type(data) == list:
             return data
         else:
             return [data]
